@@ -1,5 +1,7 @@
 import logging
+import os
 import re
+import uuid
 from datetime import datetime
 from pathlib import Path
 from urllib.parse import quote, urlencode, urlsplit
@@ -174,7 +176,7 @@ class RTorrentClient(BaseClient):
             raise FailedToExecuteException(
                 f"Minimum expected data not reached, wanted {minimum_expected_data} actual {current_expected_data}"
             )
-        destination_path = destination_path.resolve()
+        destination_path = Path(os.path.abspath(destination_path))
 
         if fast_resume:
             logger.info("Adding fast resume data")
@@ -218,21 +220,40 @@ class RTorrentClient(BaseClient):
                 )
 
         encoded_torrent = bencode(torrent)
-        cmd = [encoded_torrent]
+        cmd_args = []
+        exception = None
         if add_name_to_folder:
-            cmd.append(f'd.directory.set="{destination_path!s}"')
+            cmd_args.append(f'd.directory.set="{destination_path!s}"')
         else:
-            cmd.append(f'd.directory_base.set="{destination_path!s}"')
+            cmd_args.append(f'd.directory_base.set="{destination_path!s}"')
         if self.label:
-            cmd.append(f"d.custom1.set={quote(self.label)}")
-        logger.info(f"Sending to rtorrent: {cmd!r}")
+            cmd_args.append(f"d.custom1.set={quote(self.label)}")
+        logger.info(f"Sending to rtorrent: {cmd_args!r}")
         try:  # TODO: use torrent_temp_path if payload is too big
             if stopped:
-                self.proxy.load.raw("", *cmd)
+                self.proxy.load.raw("", *([encoded_torrent] + cmd_args))
             else:
-                self.proxy.load.raw_start("", *cmd)
-        except (XMLRPCError, ConnectionError, OSError, ExpatError):
-            raise FailedToExecuteException()
+                self.proxy.load.raw_start("", *([encoded_torrent] + cmd_args))
+        except (XMLRPCError, ConnectionError, OSError, ExpatError) as e:
+            exception = e
+        else:
+            return
+
+        # write file
+        if self.torrent_temp_path:
+            temp_torrent_file_path = self.torrent_temp_path / f"tmp_{str(uuid.uuid4())}.torrent"
+            temp_torrent_file_path.write_bytes(encoded_torrent)
+            try: # TODO: support rewriting path
+                if stopped:
+                    pass
+                else:
+                    pass
+            except (XMLRPCError, ConnectionError, OSError, ExpatError) as e:
+                raise FailedToExecuteException(f"Failed to add torrent: {e!r}")
+            finally:
+                return
+        else:
+            raise FailedToExecuteException(f"Failed to add torrent: {exception!r}")
 
     def remove(self, infohash):
         try:
@@ -340,10 +361,10 @@ class RTorrentClient(BaseClient):
         if scgi_method == "port":
             scgi_url = scgi_url.strip()
         else:
-            scgi_url = Path(scgi_url.strip()).expanduser().resolve()
+            scgi_url = Path(os.path.abspath(Path(scgi_url.strip()).expanduser()))
 
         client = cls(f"scgi://{scgi_url}")
-        session_path = Path(client.proxy.session.path()).resolve()
+        session_path = Path(os.path.abspath(Path(client.proxy.session.path())))
         if session_path.is_dir():
             client.session_path = session_path
         return client
